==> ecp_sync_plugin-3.2.2.tar.gz: ios/Classes/ViewController.swift <==
//
//  ViewController.swift
//  EncriptionSwift
//
//  Created by VCS on 06/03/19.
//  Copyright © 2019 vcs. All rights reserved.
//

import UIKit
import Foundation
import MTBBarcodeScanner
import AVFoundation
import SwiftyJSON



class ViewController: UIViewController{
     
     @IBOutlet var labCount: UILabel!
     @IBOutlet var previewView: UIView!
     var scanner: MTBBarcodeScanner?
     
     var delegate:BarcodeScannerViewControllerDelegate!
     var isSingleScan:Bool = true
     var isPlaySound:Bool = true
     var isOnFlase:Bool = true
     var themeColor:String = "#004a96"
     
     var itesm = [String]()
     var itesmNew = [String]()
     
     override func viewDidLoad() {
          super.viewDidLoad()
          
          //self.navigationController?.setNavigationBarHidden(false, animated: animated)
          self.navigationController?.navigationBar.barTintColor = hexStringToUIColor(hex: themeColor)
          self.navigationController?.navigationBar.tintColor = UIColor.white
          
          let rectShape = CAShapeLayer()
          rectShape.bounds = self.labCount.frame
          rectShape.position = self.labCount.center
          rectShape.path = UIBezierPath(roundedRect: self.labCount.bounds, byRoundingCorners: [.bottomLeft , .topLeft], cornerRadii: CGSize(width: 20, height: 20)).cgPath
          
          //self.labCount.layer.backgroundColor = hexStringToUIColor(hex: themeColor) as! CGColor
          //Here I'm masking the textView's layer with rectShape layer
          self.labCount.layer.mask = rectShape
          
          self.previewView.frame = self.view.bounds;
          scanner = MTBBarcodeScanner(previewView: previewView)
          
        
     }
     
    
     
     
     /*override func shouldAutorotate() -> Bool {
          // Lock autorotate
          return false
     }
     
     override func supportedInterfaceOrientations() -> Int {
          
          // Only allow Portrait
          return Int(UIInterfaceOrientationMask.Portrait.rawValue)
     }
     
     override func preferredInterfaceOrientationForPresentation() -> UIInterfaceOrientation {
          
          // Only allow Portrait
          return UIInterfaceOrientation.Portrait
     }*/
     
     override func viewWillTransition(to size: CGSize, with coordinator: UIViewControllerTransitionCoordinator) {
          if UIDevice.current.orientation.isLandscape {
               
               self.view.layoutIfNeeded()
               
               self.view.setNeedsLayout()
               
               self.previewView.frame = self.view.bounds;
               scanner = MTBBarcodeScanner(previewView: previewView)
          }else{
               
               self.view.layoutIfNeeded()
               
               self.view.setNeedsLayout()
               
               self.previewView.frame = self.view.bounds;
               scanner = MTBBarcodeScanner(previewView: previewView)
               //self.updateViewConstraints()
          }
     }
     
     /*override func viewWillAppear(_ animated: Bool) {
          self.navigationController?.setNavigationBarHidden(false, animated: animated)
     }*/
     
     var isClicked:Bool = false
     
     @IBAction func NextClick(_ sender: UIButton) {
          print("NextClick")
          
          if(isClicked == false){
               
               isClicked = true
               
               let myGroup = DispatchGroup()
               
               myGroup.enter()
               //print("details...")
               if(self.scanner != nil){
                    self.scanner?.stopScanning()
               }
               print("scan count:\(self.itesm.count)")
               let strr:String = jsonData(from: self.itesm)!
               print("scan json:\(strr)")
               
               self.delegate?.barcodeScannerViewController(self, didScanBarcodeWithResult: strr)
               print("buttonPressed")
               
               myGroup.leave()
               
               /*dispatch_group_notify(myGroup, dispatch_get_main_queue(), {
                self.dismiss(animated: false)
                })*/
               
               myGroup.notify(queue: DispatchQueue.main, execute: {
                    self.isClicked = false
                    self.dismiss(animated: false)
                    
               })
          }
     }
     
     func jsonData(from object:Any) -> String? {
          guard let data = try? JSONSerialization.data(withJSONObject: object, options: []) else {
               return nil
          }
          return String(data: data, encoding: String.Encoding.utf8)
     }
     
     @IBAction func backClick(_ sender: UIBarButtonItem) {
          
          print("backClick")
          
          self.delegate.barcodeScannerViewController(self, didFailWithErrorCode: "err")
          dismiss(animated: true)
     }

     
     override func viewDidAppear(_ animated: Bool) {
          super.viewDidAppear(animated)
          
          if ((scanner?.isScanning) != nil) {
               scanner?.stopScanning()
          }
          
          MTBBarcodeScanner.requestCameraPermission(success: { success in
               if success {
                    self.startScan()
               } else {
                    //self.delegate.barcodeScannerViewController(self, didFailWithErrorCode: "PERMISSION_NOT_GRANTED")
                    print("PERMISSION_NOT_GRANTED")
                    self.dismiss(animated: false)
               }
          })
          
     }
     
     override func viewWillDisappear(_ animated: Bool) {
          self.scanner?.stopScanning()
          
          super.viewWillDisappear(animated)
     }
     
     func startScan() {
          var error: Error?
          try? scanner?.startScanning(resultBlock: { codes in
               
               if(codes != nil){
                    
                    let code: AVMetadataMachineReadableCodeObject? = codes?.first
                    if code != nil {
                         
                         print("---------------")
                         print(codes)
                         print("---------------")
                         
                         var stringValue : String = (code?.stringValue)!
                         //codeScanned = stringValue
                         
                         if(stringValue != ""){
                              
                              //print("stringValue code: \(stringValue)")
                              var isGoing = false
                              
                              if(stringValue.characters.count <= 14){
                                   isGoing = true
                              }
                              
                              if(isGoing == false){
                                   let swiftyString = stringValue.replacingOccurrences(of: "\"", with: "")
                                   //print("swiftyString:\(swiftyString)")
                                   let trimmedString = swiftyString.trimmingCharacters(in: .whitespaces)
                                   //print("trimmedString:\(trimmedString)")
                                   
                                   
                                   
                                   var ites:Int = 0
                                   var finalStr:String = ""
                                   var groupSaprator:String = ""
                                   while(ites < trimmedString.characters.count){
                                        let firstChar = Array(trimmedString)[ites]
                                        
                                        let charAscii = firstChar.ascii
                                        if(charAscii != 29){
                                             finalStr = finalStr + "\(firstChar)"
                                        }else{
                                             finalStr = finalStr + "\(firstChar)"
                                             groupSaprator = "\(firstChar)"
                                        }
                                        
                                        ites = ites + 1
                                   }
                                   
                                   if(!finalStr.isEmpty){
                                        if(!groupSaprator.isEmpty){
                                             let group = finalStr.components(separatedBy: groupSaprator)
                                             //print(group)
                                             //print(group[0])
                                             //print(group[1])
                                             
                                             var str1:String = group[group.count - 1]
                                             //print(str1)
                                             if(!str1.isEmpty){
                                                  
                                                  
                                                  if let index = str1.index(str1.startIndex, offsetBy: 0, limitedBy: str1.endIndex) {
                                                       str1.remove(at: index)
                                                       //print(str1) // prints "Hello I must be going"
                                                  }
                                                  
                                                  if let index = str1.index(str1.startIndex, offsetBy: 0, limitedBy: str1.endIndex) {
                                                       str1.remove(at: index)
                                                       //print(str1) // prints "Hello I must be going"
                                                  }
                                                  
                                                  stringValue = str1
                                                  //print("stringValue : \(stringValue)")
                                             }
                                        }
                                   }
                              }
                              
                              if(!self.itesm.contains(stringValue)){
                                   print("Found code: \(stringValue)")
                                   self.itesm.append(stringValue)
                                   
                                   if(self.isPlaySound){
                                        //self.countButton.setTitle("\(self.itesm.count)", for: .normal)
                                        // create a sound ID, in this case its the tweet sound.
                                        let systemSoundID: SystemSoundID = 1017
                                        // to play sound
                                        AudioServicesPlaySystemSound (systemSoundID)
                                   }
                                   
                                  /* self.countView.setTitle("\(self.itesm.count)", for: .normal)*/
                                   
                                   self.labCount.text = "\(self.itesm.count)"
                                   
                                   if(self.isSingleScan){
                                        self.scanner?.stopScanning()
                                        
                                        self.dismiss(animated: false)
                                   }
                              }
                              
                         }
                    }
               }
          })
     }
     
     func hexStringToUIColor (hex:String) -> UIColor {
          var cString:String = hex.trimmingCharacters(in: .whitespacesAndNewlines).uppercased()
          
          if (cString.hasPrefix("#")) {
               cString.remove(at: cString.startIndex)
          }
          
          if ((cString.characters.count) != 6) {
               return UIColor.gray
          }
          
          var rgbValue:UInt32 = 0
          Scanner(string: cString).scanHexInt32(&rgbValue)
          
          return UIColor(
               red: CGFloat((rgbValue & 0xFF0000) >> 16) / 255.0,
               green: CGFloat((rgbValue & 0x00FF00) >> 8) / 255.0,
               blue: CGFloat(rgbValue & 0x0000FF) / 255.0,
               alpha: CGFloat(1.0)
          )
     }
}

/*extension Character {
     var isAscii: Bool {
          return unicodeScalars.allSatisfy { $0.isASCII }
     }
     var ascii: UInt32? {
          return isAscii ? unicodeScalars.first?.value : nil
     }
}

extension String {
     
     var length: Int {
          return count
     }
     
     subscript (i: Int) -> String {
          return self[i ..< i + 1]
     }
     
     func substring(fromIndex: Int) -> String {
          return self[min(fromIndex, length) ..< length]
     }
     
     func substring(toIndex: Int) -> String {
          return self[0 ..< max(0, toIndex)]
     }
     
     subscript (r: Range<Int>) -> String {
          let range = Range(uncheckedBounds: (lower: max(0, min(length, r.lowerBound)),
                                              upper: min(length, max(0, r.upperBound))))
          let start = index(startIndex, offsetBy: range.lowerBound)
          let end = index(start, offsetBy: range.upperBound - range.lowerBound)
          return String(self[start ..< end])
     }
     
     var bool: Bool? {
          switch self.lowercased() {
          case "true", "t", "yes", "y", "1":
               return true
          case "false", "f", "no", "n", "0":
               return false
          default:
               return nil
          }
     }
}*/

/*extension String {
 func aesEncrypt(key: String, iv: String) throws -> String{
 //let data = self.dataUsingEncoding(NSUTF8StringEncoding)
 let data1 = self.data(using: .utf8)
 let enc = try AES(key: key, iv: iv, blockMode:.CBC,padding: .pkcs7).encrypt(data1!.bytes)
 let encData = NSData(bytes: enc, length: Int(enc.count))
 let base64String: String = encData.base64EncodedString(options: NSData.Base64EncodingOptions(rawValue: 0));
 let result = String(base64String)
 return result
 }
 
 func aesDecrypt(key: String, iv: String) throws -> String {
 //let data1 = NSData(base64Encoded: self, options: NSData.Base64DecodingOptions(rawValue: 0))
 let data1 = Data(base64Encoded: self)!
 let dec = try AES(key: key, iv: iv, blockMode:.CBC,padding: .pkcs7).decrypt(Array(data1))
 let decData = NSData(bytes: dec, length: Int(dec.count))
 let result = NSString(data: decData as Data, encoding: String.Encoding.utf8.rawValue)
 //let result = String(bytes: Data(decData).bytes, encoding: .utf8)
 print(decData)
 //let result =  String(data: decData as Data, encoding: String.Encoding.utf8.rawValue)
 return String(result!)
 }
 
 func aesEncrypt1(key: String, iv: String) throws -> String {
 
 
 let pwdBytes = [UInt8](key.utf8)
 var keyBytes: [UInt8] = Array(arrayLiteral: 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0)
 var len = pwdBytes.count
 if(len > keyBytes.count){
 len = keyBytes.count
 //keyBytes = NSArray(array:b, copyItems: true) as! [UInt8]
 }
 
 var i:Int = 0
 while(i < len){
 keyBytes[i] = pwdBytes[i]
 i = i + 1
 }
 
 let key1 = keyBytes
 let iv1 = keyBytes
 
 let encrypted = try AES(key: key1, iv: iv1, blockMode:.CBC, padding: .pkcs5).encrypt([UInt8](self.data(using: .utf8)!))
 return Data(encrypted).base64EncodedString()
 }
 
 func aesDecrypt1(key: String, iv: String) throws -> String {
 
 let pwdBytes = [UInt8](key.utf8)
 var keyBytes: [UInt8] = Array(arrayLiteral: 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0)
 var len = pwdBytes.count
 if(len > keyBytes.count){
 len = keyBytes.count
 //keyBytes = NSArray(array:b, copyItems: true) as! [UInt8]
 }
 
 var i:Int = 0
 while(i < len){
 keyBytes[i] = pwdBytes[i]
 i = i + 1
 }
 
 let key1 = keyBytes
 let iv1 = keyBytes
 
 guard let data = Data(base64Encoded: self) else { return "" }
 let decrypted = try AES(key: key1, iv: iv1, blockMode:.CBC, padding: .pkcs5).decrypt([UInt8](data))
 return String(bytes: Data(decrypted).bytes, encoding: .utf8) ?? "Could not decrypt"
 }
 }*/

==> ecp_sync_plugin-3.4.7.tar.gz: ios/Classes/ViewController.swift <==
//
//  ViewController.swift
//  EncriptionSwift
//
//  Created by VCS on 06/03/19.
//  Copyright © 2019 vcs. All rights reserved.
//

import UIKit
import Foundation
import MTBBarcodeScanner
import AVFoundation
import SwiftyJSON


protocol BarcodeScannerViewControllerDelegate: NSObjectProtocol {
     func barcodeScannerViewController(_ controller: UIViewController?, didScanBarcodeWithResult result: String?)
     func barcodeScannerViewController(_ controller: UIViewController?, didFailWithErrorCode errorCode: String?)
}


class ViewController: UIViewController{
     
     @IBOutlet var labCount: UILabel!
     @IBOutlet var previewView: UIView!
     var scanner: MTBBarcodeScanner?
     
     var delegate:BarcodeScannerViewControllerDelegate!
     var isSingleScan:Bool = true
     var isPlaySound:Bool = true
     var isOnFlase:Bool = true
     var themeColor:String = "#004a96"
     
     var itesm = [String]()
     var itesmNew = [String]()
     
     override func viewDidLoad() {
          super.viewDidLoad()
          
          //self.navigationController?.setNavigationBarHidden(false, animated: animated)
          self.navigationController?.navigationBar.barTintColor = hexStringToUIColor(hex: themeColor)
          self.navigationController?.navigationBar.tintColor = UIColor.white
          
          let rectShape = CAShapeLayer()
          rectShape.bounds = self.labCount.frame
          rectShape.position = self.labCount.center
          rectShape.path = UIBezierPath(roundedRect: self.labCount.bounds, byRoundingCorners: [.bottomLeft , .topLeft], cornerRadii: CGSize(width: 20, height: 20)).cgPath
          
          //self.labCount.layer.backgroundColor = hexStringToUIColor(hex: themeColor) as! CGColor
          //Here I'm masking the textView's layer with rectShape layer
          self.labCount.layer.mask = rectShape
          
          self.previewView.frame = self.view.bounds;
          scanner = MTBBarcodeScanner(previewView: previewView)
          
        
     }
     
    
     
     
     /*override func shouldAutorotate() -> Bool {
          // Lock autorotate
          return false
     }
     
     override func supportedInterfaceOrientations() -> Int {
          
          // Only allow Portrait
          return Int(UIInterfaceOrientationMask.Portrait.rawValue)
     }
     
     override func preferredInterfaceOrientationForPresentation() -> UIInterfaceOrientation {
          
          // Only allow Portrait
          return UIInterfaceOrientation.Portrait
     }*/
     
     override func viewWillTransition(to size: CGSize, with coordinator: UIViewControllerTransitionCoordinator) {
          if UIDevice.current.orientation.isLandscape {
               
               self.view.layoutIfNeeded()
               
               self.view.setNeedsLayout()
               
               self.previewView.frame = self.view.bounds;
               scanner = MTBBarcodeScanner(previewView: previewView)
          }else{
               
               self.view.layoutIfNeeded()
               
               self.view.setNeedsLayout()
               
               self.previewView.frame = self.view.bounds;
               scanner = MTBBarcodeScanner(previewView: previewView)
               //self.updateViewConstraints()
          }
     }
     
     /*override func viewWillAppear(_ animated: Bool) {
          self.navigationController?.setNavigationBarHidden(false, animated: animated)
     }*/
     
     var isClicked:Bool = false
     
     @IBAction func NextClick(_ sender: UIButton) {
          print("NextClick")
          
          if(isClicked == false){
               
               isClicked = true
               
               let myGroup = DispatchGroup()
               
               myGroup.enter()
               //print("details...")
               if(self.scanner != nil){
                    self.scanner?.stopScanning()
               }
               print("scan count:\(self.itesm.count)")
               let strr:String = jsonData(from: self.itesm)!
               print("scan json:\(strr)")
               
               self.delegate?.barcodeScannerViewController(self, didScanBarcodeWithResult: strr)
               print("buttonPressed")
               
               myGroup.leave()
               
               /*dispatch_group_notify(myGroup, dispatch_get_main_queue(), {
                self.dismiss(animated: false)
                })*/
               
               myGroup.notify(queue: DispatchQueue.main, execute: {
                    self.isClicked = false
                    self.dismiss(animated: false)
                    
               })
          }
     }
     
     func jsonData(from object:Any) -> String? {
          guard let data = try? JSONSerialization.data(withJSONObject: object, options: []) else {
               return nil
          }
          return String(data: data, encoding: String.Encoding.utf8)
     }
     
     @IBAction func backClick(_ sender: UIBarButtonItem) {
          
          print("backClick")
          
          self.delegate.barcodeScannerViewController(self, didFailWithErrorCode: "err")
          dismiss(animated: true)
     }

     
     override func viewDidAppear(_ animated: Bool) {
          super.viewDidAppear(animated)
          
          if ((scanner?.isScanning) != nil) {
               scanner?.stopScanning()
          }
          
          MTBBarcodeScanner.requestCameraPermission(success: { success in
               if success {
                    self.startScan()
               } else {
                    //self.delegate.barcodeScannerViewController(self, didFailWithErrorCode: "PERMISSION_NOT_GRANTED")
                    print("PERMISSION_NOT_GRANTED")
                    self.dismiss(animated: false)
               }
          })
          
     }
     
     override func viewWillDisappear(_ animated: Bool) {
          self.scanner?.stopScanning()
          
          super.viewWillDisappear(animated)
     }
     
     func startScan() {
          var error: Error?
          try? scanner?.startScanning(resultBlock: { codes in
               
               if(codes != nil){
                    
                    let code: AVMetadataMachineReadableCodeObject? = codes?.first
                    if code != nil {
                         
                         print("---------------")
                         print(codes)
                         print("---------------")
                         
                         var stringValue : String = (code?.stringValue)!
                         //codeScanned = stringValue
                         
                         if(stringValue != ""){
                              
                              //print("stringValue code: \(stringValue)")
                              var isGoing = false
                              
                              if(stringValue.count <= 14){
                                   isGoing = true
                              }
                              
                              if(isGoing == false){
                                   let swiftyString = stringValue.replacingOccurrences(of: "\"", with: "")
                                   //print("swiftyString:\(swiftyString)")
                                   let trimmedString = swiftyString.trimmingCharacters(in: .whitespaces)
                                   //print("trimmedString:\(trimmedString)")
                                   
                                   
                                   
                                   var ites:Int = 0
                                   var finalStr:String = ""
                                   var groupSaprator:String = ""
                                   while(ites < trimmedString.count){
                                        let firstChar = Array(trimmedString)[ites]
                                        
                                        let charAscii = firstChar.ascii
                                        if(charAscii != 29){
                                             finalStr = finalStr + "\(firstChar)"
                                        }else{
                                             finalStr = finalStr + "\(firstChar)"
                                             groupSaprator = "\(firstChar)"
                                        }
                                        
                                        ites = ites + 1
                                   }
                                   
                                   if(!finalStr.isEmpty){
                                        if(!groupSaprator.isEmpty){
                                             let group = finalStr.components(separatedBy: groupSaprator)
                                             //print(group)
                                             //print(group[0])
                                             //print(group[1])
                                             
                                             var str1:String = group[group.count - 1]
                                             //print(str1)
                                             if(!str1.isEmpty){
                                                  
                                                  
                                                  if let index = str1.index(str1.startIndex, offsetBy: 0, limitedBy: str1.endIndex) {
                                                       str1.remove(at: index)
                                                       //print(str1) // prints "Hello I must be going"
                                                  }
                                                  
                                                  if let index = str1.index(str1.startIndex, offsetBy: 0, limitedBy: str1.endIndex) {
                                                       str1.remove(at: index)
                                                       //print(str1) // prints "Hello I must be going"
                                                  }
                                                  
                                                  stringValue = str1
                                                  //print("stringValue : \(stringValue)")
                                             }
                                        }
                                   }
                              }
                              
                              if(!self.itesm.contains(stringValue)){
                                   print("Found code: \(stringValue)")
                                   self.itesm.append(stringValue)
                                   
                                   if(self.isPlaySound){
                                        //self.countButton.setTitle("\(self.itesm.count)", for: .normal)
                                        // create a sound ID, in this case its the tweet sound.
                                        let systemSoundID: SystemSoundID = 1017
                                        // to play sound
                                        AudioServicesPlaySystemSound (systemSoundID)
                                   }
                                   
                                  /* self.countView.setTitle("\(self.itesm.count)", for: .normal)*/
                                   
                                   self.labCount.text = "\(self.itesm.count)"
                                   
                                   if(self.isSingleScan){
                                        self.scanner?.stopScanning()
                                        
                                        self.dismiss(animated: false)
                                   }
                              }
                              
                         }
                    }
               }
          })
     }
     
     func hexStringToUIColor (hex:String) -> UIColor {
          var cString:String = hex.trimmingCharacters(in: .whitespacesAndNewlines).uppercased()
          
          if (cString.hasPrefix("#")) {
               cString.remove(at: cString.startIndex)
          }
          
          if ((cString.count) != 6) {
               return UIColor.gray
          }
          
          var rgbValue:UInt32 = 0
          Scanner(string: cString).scanHexInt32(&rgbValue)
          
          return UIColor(
               red: CGFloat((rgbValue & 0xFF0000) >> 16) / 255.0,
               green: CGFloat((rgbValue & 0x00FF00) >> 8) / 255.0,
               blue: CGFloat(rgbValue & 0x0000FF) / 255.0,
               alpha: CGFloat(1.0)
          )
     }
}

/*extension Character {
     var isAscii: Bool {
          return unicodeScalars.allSatisfy { $0.isASCII }
     }
     var ascii: UInt32? {
          return isAscii ? unicodeScalars.first?.value : nil
     }
}

extension String {
     
     var length: Int {
          return count
     }
     
     subscript (i: Int) -> String {
          return self[i ..< i + 1]
     }
     
     func substring(fromIndex: Int) -> String {
          return self[min(fromIndex, length) ..< length]
     }
     
     func substring(toIndex: Int) -> String {
          return self[0 ..< max(0, toIndex)]
     }
     
     subscript (r: Range<Int>) -> String {
          let range = Range(uncheckedBounds: (lower: max(0, min(length, r.lowerBound)),
                                              upper: min(length, max(0, r.upperBound))))
          let start = index(startIndex, offsetBy: range.lowerBound)
          let end = index(start, offsetBy: range.upperBound - range.lowerBound)
          return String(self[start ..< end])
     }
     
     var bool: Bool? {
          switch self.lowercased() {
          case "true", "t", "yes", "y", "1":
               return true
          case "false", "f", "no", "n", "0":
               return false
          default:
               return nil
          }
     }
}*/

/*extension String {
 func aesEncrypt(key: String, iv: String) throws -> String{
 //let data = self.dataUsingEncoding(NSUTF8StringEncoding)
 let data1 = self.data(using: .utf8)
 let enc = try AES(key: key, iv: iv, blockMode:.CBC,padding: .pkcs7).encrypt(data1!.bytes)
 let encData = NSData(bytes: enc, length: Int(enc.count))
 let base64String: String = encData.base64EncodedString(options: NSData.Base64EncodingOptions(rawValue: 0));
 let result = String(base64String)
 return result
 }
 
 func aesDecrypt(key: String, iv: String) throws -> String {
 //let data1 = NSData(base64Encoded: self, options: NSData.Base64DecodingOptions(rawValue: 0))
 let data1 = Data(base64Encoded: self)!
 let dec = try AES(key: key, iv: iv, blockMode:.CBC,padding: .pkcs7).decrypt(Array(data1))
 let decData = NSData(bytes: dec, length: Int(dec.count))
 let result = NSString(data: decData as Data, encoding: String.Encoding.utf8.rawValue)
 //let result = String(bytes: Data(decData).bytes, encoding: .utf8)
 print(decData)
 //let result =  String(data: decData as Data, encoding: String.Encoding.utf8.rawValue)
 return String(result!)
 }
 
 func aesEncrypt1(key: String, iv: String) throws -> String {
 
 
 let pwdBytes = [UInt8](key.utf8)
 var keyBytes: [UInt8] = Array(arrayLiteral: 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0)
 var len = pwdBytes.count
 if(len > keyBytes.count){
 len = keyBytes.count
 //keyBytes = NSArray(array:b, copyItems: true) as! [UInt8]
 }
 
 var i:Int = 0
 while(i < len){
 keyBytes[i] = pwdBytes[i]
 i = i + 1
 }
 
 let key1 = keyBytes
 let iv1 = keyBytes
 
 let encrypted = try AES(key: key1, iv: iv1, blockMode:.CBC, padding: .pkcs5).encrypt([UInt8](self.data(using: .utf8)!))
 return Data(encrypted).base64EncodedString()
 }
 
 func aesDecrypt1(key: String, iv: String) throws -> String {
 
 let pwdBytes = [UInt8](key.utf8)
 var keyBytes: [UInt8] = Array(arrayLiteral: 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0)
 var len = pwdBytes.count
 if(len > keyBytes.count){
 len = keyBytes.count
 //keyBytes = NSArray(array:b, copyItems: true) as! [UInt8]
 }
 
 var i:Int = 0
 while(i < len){
 keyBytes[i] = pwdBytes[i]
 i = i + 1
 }
 
 let key1 = keyBytes
 let iv1 = keyBytes
 
 guard let data = Data(base64Encoded: self) else { return "" }
 let decrypted = try AES(key: key1, iv: iv1, blockMode:.CBC, padding: .pkcs5).decrypt([UInt8](data))
 return String(bytes: Data(decrypted).bytes, encoding: .utf8) ?? "Could not decrypt"
 }
 }*/
